pub fn tracing_layer<S>(
service_name: &str,
) -> Result<OpenTelemetryLayer<S, Tracer>>where
S: Subscriber + for<'span> LookupSpan<'span>,Expand description
Build the OTLP tracing layer wired up to the configured Collector endpoint.
pub fn tracing_layer<S>(
service_name: &str,
) -> Result<OpenTelemetryLayer<S, Tracer>>where
S: Subscriber + for<'span> LookupSpan<'span>,Build the OTLP tracing layer wired up to the configured Collector endpoint.